package com.link.core.util;

import com.link.core.util.Base64Util;
import com.link.core.util.CoreYmlConstants;
import com.link.core.util.StringUtils;
import javax.crypto.Cipher;
import javax.crypto.KeyGenerator;
import javax.crypto.SecretKey;
import javax.crypto.spec.GCMParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import org.apache.commons.codec.binary.Base64;

public class AesUtil {

   private static final String AES_METHOD = "AES/GCM/NoPadding";
   private static final String AES_ECB_METHOD = "AES/ECB/PKCS5Padding";


   public static String encrypt(String sSrc) throws Exception {
      return encrypt(sSrc, CoreYmlConstants.getAesSecretkey());
   }

   public static String encrypt(String sSrc, String sKey) throws Exception {
      if(StringUtils.isNull(sKey)) {
         System.out.print("加密密码为空！");
         return sSrc;
      } else if(sKey.length() != 16) {
         System.out.print("加密密码长度必须为16位！");
         return sSrc;
      } else {
         byte[] raw = sKey.getBytes("utf-8");
         SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
         Cipher cipher = Cipher.getInstance("AES/GCM/NoPadding");
         cipher.init(1, skeySpec);
         byte[] iv = cipher.getIV();

         assert iv.length == 12;

         byte[] encryptData = cipher.doFinal(sSrc.getBytes());

         assert encryptData.length == sSrc.getBytes().length + 16;

         byte[] message = new byte[12 + sSrc.getBytes().length + 16];
         System.arraycopy(iv, 0, message, 0, 12);
         System.arraycopy(encryptData, 0, message, 12, encryptData.length);
         return Base64.encodeBase64String(message);
      }
   }

   public static String decrypt(String sSrc) throws Exception {
      return decrypt(sSrc, CoreYmlConstants.getAesSecretkey());
   }

   public static String decrypt(String sSrc, String sKey) throws Exception {
      try {
         if(StringUtils.isNull(sKey)) {
            System.out.print("加密密码为空！");
            return sSrc;
         } else if(sKey.length() != 16) {
            System.out.print("加密密码长度必须是16位！");
            return sSrc;
         } else {
            byte[] ex = sKey.getBytes("utf-8");
            SecretKeySpec skeySpec = new SecretKeySpec(ex, "AES");
            Cipher cipher = Cipher.getInstance("AES/GCM/NoPadding");
            byte[] message = Base64.decodeBase64(sSrc);
            if(message.length < 28) {
               throw new IllegalArgumentException();
            } else {
               GCMParameterSpec params = new GCMParameterSpec(128, message, 0, 12);
               cipher.init(2, skeySpec, params);

               try {
                  byte[] e = cipher.doFinal(message, 12, message.length - 12);
                  String originalString = new String(e);
                  return originalString;
               } catch (Exception var9) {
                  System.out.println(var9.toString());
                  return sSrc;
               }
            }
         }
      } catch (Exception var10) {
         System.out.println(var10.toString());
         return sSrc;
      }
   }

   public static void main(String[] args) throws Exception {
      String s = "hello,您好";
      System.out.println("明文:" + s);
      String s1 = encrypt(s, "111111111111111111111111");
      System.out.println("加密:" + s1);
      System.out.println("解密:" + decrypt(s1, "111111111111111111111111"));
   }

   public static String decryptToBase64(String sSrc, String sKey) throws Exception {
      try {
         if(StringUtils.isNull(sKey)) {
            System.out.print("加密密码为空！");
            return sSrc;
         } else if(sKey.length() != 16) {
            System.out.print("加密密码长度必须是16位！");
            return sSrc;
         } else {
            byte[] ex = sKey.getBytes("utf-8");
            SecretKeySpec skeySpec = new SecretKeySpec(ex, "AES");
            Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");
            cipher.init(2, skeySpec);
            byte[] encrypted1 = Base64Util.decode(sSrc);

            try {
               byte[] e = cipher.doFinal(encrypted1);
               String originalString = new String(e, "utf-8");
               return originalString;
            } catch (Exception var8) {
               System.out.println(var8.toString());
               return sSrc;
            }
         }
      } catch (Exception var9) {
         System.out.println(var9.toString());
         return sSrc;
      }
   }

   public static String generateDesKey(int length) throws Exception {
      KeyGenerator kgen = null;
      kgen = KeyGenerator.getInstance("AES");
      kgen.init(length);
      SecretKey skey = kgen.generateKey();
      return byteToHexString(skey.getEncoded());
   }

   private static String byteToHexString(byte[] bytes) {
      StringBuffer sb = new StringBuffer();

      for(int i = 0; i < bytes.length; ++i) {
         String strHex = Integer.toHexString(bytes[i]);
         if(strHex.length() > 3) {
            sb.append(strHex.substring(6));
         } else if(strHex.length() < 2) {
            sb.append("0" + strHex);
         } else {
            sb.append(strHex);
         }
      }

      return sb.toString();
   }

}
